@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-24581272f18a54589fb73a1cd91e0b2a
-key: yesod_KfMjSXlKv5e8tD1piQliVs
+id: yesod-1.4.2-36be845f4f1d6637b31b996096fb7b64
+key: yesod_B5n4gF9sbIqGw6CiPJKWF8
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,19 +21,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-KfMjSXlKv5e8tD1piQliVs
+hs-libraries: HSyesod-1.4.2-B5n4gF9sbIqGw6CiPJKWF8
 depends:
     aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.10-5c65857e3dfbc5cf563dbabcd22bcb07
+    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-a683e9144d2ab3af8ae3a68dc302663b
+    monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
     shakespeare-2.0.7-423d40cf84610c6e09dcfa0707b6b283
@@ -48,10 +48,10 @@ depends:
     wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
     warp-3.2.1-dece252cc38d42a08927d0fe50612a60
     yaml-0.8.16-de73bc65fca64164779e57dd8dda918f
-    yesod-auth-1.4.12-e58a3090bd2764c04ef7822f42d1403d
-    yesod-core-1.4.19-f94297912772afb605ff1791d2dab9fe
-    yesod-form-1.4.6-4f2ae85358c19dfa40e5f60d013027e8
-    yesod-persistent-1.4.0.3-6e3d26506c305c8a420f31554bf04139
+    yesod-auth-1.4.12-697811d5ea6b1ea512e38d809f5294a9
+    yesod-core-1.4.19-f58e956f86f9387c891d6fa112ae88e5
+    yesod-form-1.4.6-0d16987bed7ae5bd9138bcaf56057062
+    yesod-persistent-1.4.0.3-3edc22929bdc95f8a7aaec30b1c13cd6
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
